@@ -15,14 +15,16 @@ See more about why we use errors here:
 https://stackoverflow.com/questions/16138232/is-it-a-good-practice-to-use-try-except-else-in-python
 """
 import traceback
-from typing import Set, List
+from typing import Any, Collection, Set, List
+
+from mitosheet.types import ColumnHeader
 
 
 class MitoError(Exception):
     """
     An error that occurs during the processing of an editing event.
     """
-    def __init__(self, type_, header, to_fix, error_modal=True):
+    def __init__(self, type_: str, header: str, to_fix: str, error_modal: bool=True):
         """
         Creates a creation error. 
 
@@ -35,7 +37,7 @@ class MitoError(Exception):
         self.to_fix = to_fix
         self.error_modal = error_modal
 
-def make_no_sheet_error(sheet_indexes: Set[int]):
+def make_no_sheet_error(sheet_indexes: Set[int]) -> MitoError:
     """
     Helper function for creating a no_sheet_error.
 
@@ -49,7 +51,7 @@ def make_no_sheet_error(sheet_indexes: Set[int]):
         to_fix
     )
 
-def make_incompatible_merge_headers_error(error_modal=True):
+def make_incompatible_merge_headers_error(error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a incompatible_merge_headers_error
 
@@ -65,7 +67,7 @@ def make_incompatible_merge_headers_error(error_modal=True):
         error_modal=error_modal
     )
 
-def make_incompatible_merge_key_error(error_modal=True):
+def make_incompatible_merge_key_error(error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a incompatible_merge_key_error
 
@@ -80,7 +82,7 @@ def make_incompatible_merge_key_error(error_modal=True):
         error_modal=error_modal
     )
 
-def make_no_column_error(column_headers: Set[str], error_modal=True):
+def make_no_column_error(column_headers: Collection[ColumnHeader], error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a no_column_error.
 
@@ -89,7 +91,7 @@ def make_no_column_error(column_headers: Set[str], error_modal=True):
     if len(column_headers) == 1:
         to_fix = f'Sorry, there is no column with the name {next(iter(column_headers))}. Did you type it correctly?'
     else:
-        to_fix = f'Sorry, there are no column with the names {", ".join(column_headers)}. Did you type them correctly?'
+        to_fix = f'Sorry, there are no column with the names {", ".join(map(str, column_headers))}. Did you type them correctly?'
 
     return MitoError(
         'no_column_error', 
@@ -98,7 +100,7 @@ def make_no_column_error(column_headers: Set[str], error_modal=True):
         error_modal=error_modal
     )
 
-def make_column_exists_error(column_header: str):
+def make_column_exists_error(column_header: ColumnHeader) -> MitoError:
     """
     Helper function for creating a column_exists_error.
 
@@ -111,7 +113,7 @@ def make_column_exists_error(column_header: str):
         f'Sorry, a column already exists with the name {column_header}. Try picking a different name!'
     )
 
-def make_invalid_formula_error(formula: str, to_fix=None, error_modal=True):
+def make_invalid_formula_error(formula: str, to_fix: str=None, error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a invalid_formula_error.
 
@@ -129,7 +131,7 @@ def make_invalid_formula_error(formula: str, to_fix=None, error_modal=True):
     )
 
 
-def make_cast_value_to_type_error(value: str, target_type: str, error_modal=True):
+def make_cast_value_to_type_error(value: str, target_type: str, error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a cast_value_to_type_error.
 
@@ -144,7 +146,7 @@ def make_cast_value_to_type_error(value: str, target_type: str, error_modal=True
         error_modal=error_modal
     )
 
-def make_circular_reference_error(error_modal=True):
+def make_circular_reference_error(error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a circular_reference_error.
 
@@ -158,7 +160,7 @@ def make_circular_reference_error(error_modal=True):
         error_modal=error_modal
     )
 
-def make_wrong_column_metatype_error(column_header: str, error_modal=True):
+def make_wrong_column_metatype_error(column_header: ColumnHeader, error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a wrong_column_metatype_error.
 
@@ -172,14 +174,14 @@ def make_wrong_column_metatype_error(column_header: str, error_modal=True):
         error_modal=error_modal
     )
 
-def make_invalid_column_headers_error(column_headers: List[str]):
+def make_invalid_column_headers_error(column_headers: List[ColumnHeader]) -> MitoError:
     """
     Helper function for creating a invalid_column_headers_error.
 
     Occurs when:
     -  a user creates (or renames) a column(s) that has an invalid name.
     """
-    to_fix = f'All headers in the dataframe must contain at least one letter and no symbols other than numbers and "_". Invalid headers: {", ".join(column_headers)}'
+    to_fix = f'All headers in the dataframe must contain at least one letter and no symbols other than numbers and "_". Invalid headers: {", ".join(map(str, column_headers))}'
 
     return MitoError(
         'invalid_column_header_error',
@@ -187,7 +189,7 @@ def make_invalid_column_headers_error(column_headers: List[str]):
         to_fix
     )
 
-def make_function_error(function_name, error_modal=True):
+def make_function_error(function_name: str, error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a function_error.
 
@@ -203,7 +205,7 @@ def make_function_error(function_name, error_modal=True):
     )
 
 
-def make_execution_error(error_modal=True):
+def make_execution_error(error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a execution_error.
 
@@ -218,7 +220,7 @@ def make_execution_error(error_modal=True):
         error_modal=error_modal
     )
 
-def make_function_execution_error(function):
+def make_function_execution_error(function: str) -> MitoError:
     """
     Helper function for creating a function_execution_error.
 
@@ -232,7 +234,7 @@ def make_function_execution_error(function):
         f'Sorry, there was an error in the {function}. Please check the documentation to make sure you called it correctly.'
     )
 
-def make_unsupported_function_error(functions: Set[str], error_modal=True):
+def make_unsupported_function_error(functions: Set[str], error_modal: bool=True) -> MitoError:
     """
     Helper function for creating a unsupported_function_error.
 
@@ -252,23 +254,21 @@ def make_unsupported_function_error(functions: Set[str], error_modal=True):
         error_modal=error_modal
     )
 
-def make_invalid_column_delete_error(column_headers, dependents):
+def make_invalid_column_delete_error(column_headers: Collection[ColumnHeader], dependents: Collection[ColumnHeader]) -> MitoError:
     """
     Helper function for creating a invalid_column_delete_error.
 
     Occurs when:
     -  the user deletes a column that is referenced by other columns
     """
-    # We make sure it's a list, for easy accessing!
-    dependents = list(dependents)
 
     return MitoError(
         'invalid_column_delete_error',
         'Column Has Dependents',
-        f'{(", ").join(column_headers)} cannot be deleted, as {"they are" if len(column_headers) > 1 else "it is"} referenced in {(", ".join(dependents))}. Please remove these references before deleting.'
+        f'{(", ").join(map(str, column_headers))} cannot be deleted, as {"they are" if len(column_headers) > 1 else "it is"} referenced in {(", ".join(map(str, dependents)))}. Please remove these references before deleting.'
     )
 
-def make_invalid_arguments_error(function):
+def make_invalid_arguments_error(function: str) -> MitoError:
     """
     Helper function for creating a invalid_arguments_error.
 
@@ -281,7 +281,7 @@ def make_invalid_arguments_error(function):
         f'It looks like you passed the wrong arguments to {function}. Try checking out the documentation to see correct usage!'
     )
 
-def make_invalid_aggregation_error():
+def make_invalid_aggregation_error() -> MitoError:
     """
     Helper function for creating a invalid_aggregation_error.
 
@@ -295,7 +295,7 @@ def make_invalid_aggregation_error():
         f'Sorry, you tried to aggregate with a function that could not be applied to that type of column. Please try again!'
     )
 
-def make_invalid_filter_error(filter_value, correct_type):
+def make_invalid_filter_error(filter_value: Any, correct_type: str) -> MitoError:
     """
     Helper function for creating a invalid_filter_error.
 
@@ -317,7 +317,7 @@ def make_invalid_filter_error(filter_value, correct_type):
         f'Sorry, the value {filter_value} is not a valid value for that {correct_type} filter. Please enter a value {correct_format}!'
     )
 
-def make_invalid_sort_error(column_header):
+def make_invalid_sort_error(column_header: ColumnHeader) -> MitoError:
     """
     Helper function for creating a invalid_sort_error.
 
@@ -332,7 +332,7 @@ def make_invalid_sort_error(column_header):
         f'Sorry, the column {column_header} has mixed data types. Please make sure the column has one datatype before trying to sort.'
     )
 
-def make_df_exists_error(df_name):
+def make_df_exists_error(df_name: str) -> MitoError:
     """
     Helper function for creating a df_exists_error.
 
@@ -347,7 +347,7 @@ def make_df_exists_error(df_name):
         f'Sorry, the dataframe {df_name} already exists. Please pick a different name.'
     )
 
-def make_invalid_column_type_change_error(column_header, old_dtype, new_dtype):
+def make_invalid_column_type_change_error(column_header: ColumnHeader, old_dtype: str, new_dtype: str) -> MitoError:
     """
     Helper function for creating a invalid_column_type_change_error.
 
@@ -362,7 +362,7 @@ def make_invalid_column_type_change_error(column_header, old_dtype, new_dtype):
         f'Sorry, the column {column_header} has a type {old_dtype}, which cannot be changed to the type {new_dtype}.'
     )
 
-def make_invalid_pivot_error():
+def make_invalid_pivot_error() -> MitoError:
     """
     Helper function for creating a invalid_pivot_error.
 
@@ -377,7 +377,7 @@ def make_invalid_pivot_error():
     )
 
 
-def make_is_directory_error(file_name):
+def make_is_directory_error(file_name: str) -> MitoError:
     """
     Helper function for creating directory_error
 
@@ -398,7 +398,7 @@ ARG_FULL_NAME = {
     'bool': 'boolean'
 }
 
-def make_operator_type_error(operator, arg_one_type, arg_two_type):
+def make_operator_type_error(operator: str, arg_one_type: str, arg_two_type: str) -> MitoError:
     """
     Helper function for creating a operator_type_error.
 
@@ -425,10 +425,10 @@ def make_operator_type_error(operator, arg_one_type, arg_two_type):
         to_fix
     )
 
-def get_recent_traceback():
+def get_recent_traceback() -> str:
     return traceback.format_exc()
 
-def get_recent_traceback_as_list():
+def get_recent_traceback_as_list() -> List[str]:
     """
     Helper function for getting the traceback of the most recent error.
     
