@@ -24,6 +24,7 @@ from mitosheet.errors import (
     make_unsupported_function_error, 
     make_wrong_column_metatype_error
 )
+from mitosheet.types import ColumnHeader, ColumnID
 
 class SetColumnFormulaStepPerformer(StepPerformer):
     """
@@ -49,7 +50,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         return 'set_column_formula_edit'
 
     @classmethod
-    def saturate(cls, prev_state: State, params) -> Dict[str, str]:
+    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         sheet_index = params['sheet_index']
         column_id = params['column_id']
         params['old_formula'] = prev_state.column_spreadsheet_code[sheet_index][column_id]
@@ -75,7 +76,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         cls,
         prev_state: State,
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         old_formula: str,
         new_formula: str,
         **params
@@ -161,7 +162,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         old_formula: str,
         new_formula: str
     ) -> List[str]:
@@ -174,7 +175,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
     def describe( # type: ignore
         cls,
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         old_formula: str,
         new_formula: str,
         df_names=None,
@@ -189,7 +190,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
     def get_modified_dataframe_indexes( # type: ignore
         cls, 
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         old_formula: str,
         new_formula: str,
         **params
@@ -200,11 +201,11 @@ class SetColumnFormulaStepPerformer(StepPerformer):
 def _update_column_formula_in_step(
         post_state: State,
         sheet_index: int,
-        column_id: str,
+        column_id: ColumnID,
         old_formula: str,
         new_formula: str,
         update_from_rename: bool=False
-    ):
+    ) -> None:
     """
     A  helper function for updating the formula of a column. It assumes
     that the passed information is all _correct_ and will not:
@@ -244,8 +245,8 @@ def _update_column_formula_in_step(
 
 def _get_fixed_invalid_formula(
         new_formula: str, 
-        column_header: Any, 
-        column_headers: List[Any]
+        column_header: ColumnHeader, 
+        column_headers: List[ColumnHeader]
     ) -> str:
     """
     A helper function that, given a formula, will try and fix
@@ -276,7 +277,7 @@ def _get_fixed_invalid_formula(
     return new_formula
 
 
-def get_details_from_operator_type_error(error):
+def get_details_from_operator_type_error(error: TypeError) -> Optional[Tuple[str, str, str]]:
     """
     We detect operator errors by checking the error string, which has the format:
 
@@ -330,7 +331,7 @@ def get_details_from_operator_type_error(error):
     return None
 
 
-def refresh_dependant_columns(post_state: State, df: pd.DataFrame, sheet_index: int):
+def refresh_dependant_columns(post_state: State, df: pd.DataFrame, sheet_index: int) -> None:
     """
     Helper function for refreshing the columns that are dependant on the column we are changing. 
     """
@@ -367,7 +368,7 @@ def refresh_dependant_columns(post_state: State, df: pd.DataFrame, sheet_index:
 def transpile_dependant_columns(
         post_state: State, 
         sheet_index: int, 
-        column_id: str
+        column_id: ColumnID
     ) -> List[str]: 
     """
     Use this helper function when making a change to a column and you want to transpile
